Class: Rubino::LLM::ToolCallRecovery::Recovered

Inherits:
Struct
  • Object
show all
Defined in:
lib/rubino/llm/tool_call_recovery.rb

Overview

text: is the content with all recovered markup removed (what the user sees and what gets saved); calls: is the list of recovered tool calls, each arguments: with arguments a Hash.

Instance Attribute Summary collapse

Instance Attribute Details

#callsObject

Returns the value of attribute calls

Returns:

  • (Object)

    the current value of calls



33
34
35
# File 'lib/rubino/llm/tool_call_recovery.rb', line 33

def calls
  @calls
end

#textObject

Returns the value of attribute text

Returns:

  • (Object)

    the current value of text



33
34
35
# File 'lib/rubino/llm/tool_call_recovery.rb', line 33

def text
  @text
end