Class: Rubino::LLM::ToolCallRecovery::Recovered
- Inherits:
-
Struct
- Object
- Struct
- Rubino::LLM::ToolCallRecovery::Recovered
- Defined in:
- lib/rubino/llm/tool_call_recovery.rb
Overview
text: is the content with all recovered markup removed (what the user sees and what gets saved); calls: is the list of recovered tool calls, each arguments: with arguments a Hash.
Instance Attribute Summary collapse
-
#calls ⇒ Object
Returns the value of attribute calls.
-
#text ⇒ Object
Returns the value of attribute text.
Instance Attribute Details
#calls ⇒ Object
Returns the value of attribute calls
33 34 35 |
# File 'lib/rubino/llm/tool_call_recovery.rb', line 33 def calls @calls end |
#text ⇒ Object
Returns the value of attribute text
33 34 35 |
# File 'lib/rubino/llm/tool_call_recovery.rb', line 33 def text @text end |